/*
 * Copyright (c) 2001, Swedish Institute of Computer Science.
 * All rights reserved. 
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met: 
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright 
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution. 
 *
 * 3. Neither the name of the Institute nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE. 
 *
 * This file is part of the lwIP TCP/IP stack.
 * 
 * Author: Adam Dunkels <adam@sics.se>
 *
 * $Id: ip_proxy.h,v 1.6 2001/02/06 10:48:19 adam Exp $
 */
#ifndef __IP_PROXY_H__
#define __IP_PROXY_H__

#include "lwip/pbuf.h"

#include "lwip/ip_addr.h"

#define IP_PROTO_ICMP 1
#define IP_PROTO_TCP 6

#define IP_HLEN 20

#define IP_ADDR_ANY 0

/* This is passed as the destination address to ip_output_if (not
   to ip_output), meaning that an IP header already is constructed
   in the pbuf. This is used when TCP retransmits. */
#ifdef IP_HDRINCL
#undef IP_HDRINCL
#endif /* IP_HDRINCL */
#define IP_HDRINCL  NULL

struct ip_hdr {
#if BYTE_ORDER == LITTLE_ENDIAN
  unsigned char hl:4,                /* header length */
    v:4;                             /* version */
#else
  unsigned char v:4,                 /* version */
    hl:4;                            /* header length */
#endif
  unsigned char tos;                 /* type of service */
  unsigned short len;                /* total length */
  unsigned short id;                 /* identification */
  unsigned short offset;             /* fragment offset field */
#define IP_RF 0x8000                 /* reserved fragment flag */
#define IP_DF 0x4000                 /* dont fragment flag */
#define IP_MF 0x2000                 /* more fragments flag */
#define IP_OFFMASK 0x1fff            /* mask for fragmenting bits */
  unsigned char ttl;                 /* time to live */
  unsigned char proto;               /* protocol */
  unsigned short chksum;             /* checksum */
  struct ip_addr src, dest;
};


void ip_init(void);
struct netif *ip_route(struct ip_addr *dest);
void ip_input(struct pbuf *p, struct netif *inp);
void ip_output_if(struct pbuf *p, struct ip_addr *src, struct ip_addr *dest,
		  unsigned char ttl, unsigned char proto,
		  struct netif *netif);
void ip_output(struct pbuf *p, struct ip_addr *src, struct ip_addr *dest,
	       unsigned char ttl, unsigned char proto);


void ip_debug_print(struct pbuf *p);

#endif /* __IP_PROXY_H__ */
