/*
 * Copyright (c) 2001, Swedish Institute of Computer Science.
 * All rights reserved. 
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met: 
 *
 * 1. Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright 
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the distribution. 
 *
 * 3. Neither the name of the Institute nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS 
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE. 
 *
 * This file is part of the lwIP TCP/IP stack.
 * 
 * Author: Adam Dunkels <adam@sics.se>
 *
 * $Id: mem.c,v 1.7 2001/02/06 10:48:19 adam Exp $
 */

#include <stdlib.h>

#include "lwip/debug.h"
#include "lwip/mem.h"

#include "lwip/stats.h"
/*-----------------------------------------------------------------------------------*/
void *
#ifdef MEM_TRACKING 
_mem_malloc(unsigned int size, char *file, int line)
#else /* MEM_TRACKING */
mem_malloc(unsigned int size)
#endif /* MEM_TRACKING */
{
  void *mem;
  mem = malloc(size);
  if(mem == NULL) {
    perror("proxy/mem.c: malloc failed");
    abort();
  }
  return mem;
}
/*-----------------------------------------------------------------------------------*/
void
#ifdef MEM_TRACKING 
_mem_free(void *rmem, char *file, int line)
#else /* MEM_TRACKING */
mem_free(void *rmem)
#endif /* MEM_TRACKING */
{
  free(rmem);
}
/*-----------------------------------------------------------------------------------*/
void *
#ifdef MEM_TRACKING
_mem_realloc(void *rmem, unsigned int newsize, char *file, int line)
#else
mem_realloc(void *rmem, unsigned int newsize)
#endif /* MEM_TRACKING */
{
  return rmem;
}
/*-----------------------------------------------------------------------------------*/
void
mem_debug_print()
{
}
/*-----------------------------------------------------------------------------------*/
void
mem_init()     
{
}
/*-----------------------------------------------------------------------------------*/

